function v=compute_ekman_surge_aen(vmax,rmax,r35,vt,phi,phi_in,w,a,n,lat)
% Computes ekman_surge_aen
% Script automatically generated by fit_ekman_surge_aen.m
% Inputs : 
% vmax           = Vmax (km/h)
% rmax           = Rmax (km)
% r35            = R35 (km)
% vt             = forward speed (km/h)
% phi            = track angle (deg)
% phi_in         = inflow angle (deg)
% w              = shelf width (km)
% a              = Dean slope a (-)
% n              = Mannings n
% lat            = latitude (deg)

% R2    = 0.85122
% RMSE  = 0.12173
% MEAN  = 0.41031
% RANGE = 0.028343 - 1.2966

beta( 1 )= 2.6546e-06 ;
beta( 2 )= 3.9168e-02 ;
beta( 3 )= 4.8893e-01 ;
beta( 4 )= -3.7508e-01 ;
beta( 5 )= -5.2177e+01 ;
beta( 6 )= 7.9252e-01 ;
beta( 7 )= 3.4154e-01 ;
beta( 8 )= 8.3607e-01 ;
beta( 9 )= -4.0460e-01 ;
beta( 10 )= -1.6280e-01 ;
beta( 11 )= 2.2051e-01 ;

v=beta(1) * exp(-a/beta(2)) .* w.^beta(3) .* (1+beta(4)*sin((phi-beta(5))*pi/180))  .* vmax.^beta(6)  .* r35.^beta(7)  .* lat.^beta(8)  .* n.^beta(9) .* vt.^beta(10)  .* rmax.^beta(11);
